@@ -10,8 +10,8 @@
  *  http://www.boost.org/LICENSE_1_0.txt)
  **************************************************************************/
 
-#ifndef STXXL_SORT_BASE_HEADER
-#define STXXL_SORT_BASE_HEADER
+#ifndef STXXL_ALGO_SORT_BASE_HEADER
+#define STXXL_ALGO_SORT_BASE_HEADER
 
 #include <cmath>
 #include <stxxl/bits/common/types.h>
@@ -35,15 +35,15 @@
 #define STXXL_L2_SIZE  (512 * 1024)
 #endif
 
-__STXXL_BEGIN_NAMESPACE
+STXXL_BEGIN_NAMESPACE
 
 // Optimal merging: merge r = pow(nruns,1/ceil(log(nruns)/log(m))) runs at once
 inline unsigned_type optimal_merge_factor(unsigned_type num_runs, unsigned_type max_concurrent_runs)
 {
-    return unsigned_type(ceil(pow(num_runs, 1. / ceil(log(double(num_runs)) / log(double(max_concurrent_runs))))));
+    return unsigned_type(ceil(pow(double(num_runs), 1. / ceil(log(double(num_runs)) / log(double(max_concurrent_runs))))));
 }
 
-__STXXL_END_NAMESPACE
+STXXL_END_NAMESPACE
 
-#endif // !STXXL_SORT_BASE_HEADER
+#endif // !STXXL_ALGO_SORT_BASE_HEADER
 // vim: et:ts=4:sw=4
