@@ -10,21 +10,21 @@
  *  http://www.boost.org/LICENSE_1_0.txt)
  **************************************************************************/
 
-#ifndef STXXL_SEED_HEADER
-#define STXXL_SEED_HEADER
+#ifndef STXXL_COMMON_SEED_HEADER
+#define STXXL_COMMON_SEED_HEADER
 
 #include <stxxl/bits/namespace.h>
 
 
-__STXXL_BEGIN_NAMESPACE
+STXXL_BEGIN_NAMESPACE
 
-//! \brief set the global stxxl seed value
+//! set the global stxxl seed value
 void set_seed(unsigned seed);
 
-//! \brief get a seed value for prng initialization,
-//!        subsequent calls return a sequence of different values
+//! get a seed value for prng initialization, subsequent calls return a
+//! sequence of different values
 unsigned get_next_seed();
 
-__STXXL_END_NAMESPACE
+STXXL_END_NAMESPACE
 
-#endif // !STXXL_SEED_HEADER
+#endif // !STXXL_COMMON_SEED_HEADER
