@@ -4,14 +4,15 @@
  *  Part of the STXXL. See http://stxxl.sourceforge.net
  *
  *  Copyright (C) 2002 Roman Dementiev <dementiev@mpi-sb.mpg.de>
+ *  Copyright (C) 2008 Andreas Beckmann <beckmann@cs.uni-frankfurt.de>
  *
  *  Distributed under the Boost Software License, Version 1.0.
  *  (See accompanying file LICENSE_1_0.txt or copy at
  *  http://www.boost.org/LICENSE_1_0.txt)
  **************************************************************************/
 
-#ifndef STXXL_IO_HEADER
-#define STXXL_IO_HEADER
+#ifndef STXXL_IO_IO_HEADER
+#define STXXL_IO_IO_HEADER
 
 #include <stxxl/request>
 #include <stxxl/bits/io/file.h>
@@ -26,11 +27,18 @@
 #include <stxxl/bits/io/create_file.h>
 #include <stxxl/bits/io/disk_queues.h>
 #include <stxxl/bits/io/iostats.h>
+#include <stxxl/bits/namespace.h>
 
+//! \c STXXL library namespace
+STXXL_BEGIN_NAMESPACE
 
-//! \brief \c \<stxxl\> library namespace
-__STXXL_BEGIN_NAMESPACE
+//! \defgroup iolayer I/O Primitives Layer
+//! Group of classes which enable abstraction from operating system calls and support
+//! system-independent interfaces for asynchronous I/O.
+//! \{
 
-__STXXL_END_NAMESPACE
+//! \}
 
-#endif // !STXXL_IO_HEADER
+    STXXL_END_NAMESPACE
+
+#endif // !STXXL_IO_IO_HEADER
