@@ -11,30 +11,31 @@
  *  http://www.boost.org/LICENSE_1_0.txt)
  **************************************************************************/
 
-#ifndef STXXL_IO__REQUEST_WITH_WAITERS_H_
-#define STXXL_IO__REQUEST_WITH_WAITERS_H_
+#ifndef STXXL_IO_REQUEST_WITH_WAITERS_HEADER
+#define STXXL_IO_REQUEST_WITH_WAITERS_HEADER
 
 #include <set>
 
 #include <stxxl/bits/common/mutex.h>
-#include <stxxl/bits/common/switch.h>
+#include <stxxl/bits/common/onoff_switch.h>
 #include <stxxl/bits/io/request_interface.h>
+#include <stxxl/bits/namespace.h>
 
 
-__STXXL_BEGIN_NAMESPACE
+STXXL_BEGIN_NAMESPACE
 
 //! \addtogroup fileimpl
 //! \{
 
-//! \brief Request that is aware of threads waiting for it to complete.
+//! Request that is aware of threads waiting for it to complete.
 class request_with_waiters : virtual public request_interface
 {
     mutex waiters_mutex;
-    std::set<onoff_switch *> waiters;
+    std::set<onoff_switch*> waiters;
 
 protected:
-    bool add_waiter(onoff_switch * sw);
-    void delete_waiter(onoff_switch * sw);
+    bool add_waiter(onoff_switch* sw);
+    void delete_waiter(onoff_switch* sw);
     void notify_waiters();
     /*
     int nwaiters();             // returns number of waiters
@@ -43,7 +44,7 @@ protected:
 
 //! \}
 
-__STXXL_END_NAMESPACE
+STXXL_END_NAMESPACE
 
-#endif // !STXXL_IO__REQUEST_WITH_WAITERS_H_
+#endif // !STXXL_IO_REQUEST_WITH_WAITERS_HEADER
 // vim: et:ts=4:sw=4
