@@ -10,15 +10,16 @@
  *  http://www.boost.org/LICENSE_1_0.txt)
  **************************************************************************/
 
-#ifndef STXXL_BUF_ISTREAM_HEADER
-#define STXXL_BUF_ISTREAM_HEADER
+#ifndef STXXL_MNG_BUF_ISTREAM_HEADER
+#define STXXL_MNG_BUF_ISTREAM_HEADER
 
 #include <stxxl/bits/mng/config.h>
 #include <stxxl/bits/mng/block_prefetcher.h>
+#include <stxxl/bits/noncopyable.h>
 #include <stxxl/bits/algo/async_schedule.h>
 
 
-__STXXL_BEGIN_NAMESPACE
+STXXL_BEGIN_NAMESPACE
 
 //! \addtogroup schedlayer
 //! \{
@@ -28,25 +29,26 @@ __STXXL_BEGIN_NAMESPACE
 #define BUF_ISTREAM_CHECK_END
 
 
-//! \brief Buffered input stream
+//! Buffered input stream.
 //!
 //! Reads data records from the stream of blocks.
 //! \remark Reading performed in the background, i.e. with overlapping of I/O and computation
-template <typename BlkTp_, typename BIDIteratorTp_>
-class buf_istream
+template <typename BlockType, typename BIDIteratorType>
+class buf_istream : private noncopyable
 {
-    typedef BlkTp_ block_type;
-    typedef BIDIteratorTp_ bid_iterator_type;
+public:
+    typedef BlockType block_type;
+    typedef BIDIteratorType bid_iterator_type;
 
+private:
     buf_istream() { }
 
 protected:
     typedef block_prefetcher<block_type, bid_iterator_type> prefetcher_type;
-    prefetcher_type * prefetcher;
-    bid_iterator_type begin_bid, end_bid;
+    prefetcher_type* prefetcher;
     int_type current_elem;
-    block_type * current_blk;
-    int_type * prefetch_seq;
+    block_type* current_blk;
+    int_type* prefetch_seq;
 #ifdef BUF_ISTREAM_CHECK_END
     bool not_finished;
 #endif
@@ -55,7 +57,7 @@ public:
     typedef typename block_type::reference reference;
     typedef buf_istream<block_type, bid_iterator_type> _Self;
 
-    //! \brief Constructs input stream object
+    //! Constructs input stream object.
     //! \param _begin \c bid_iterator pointing to the first block of the stream
     //! \param _end \c bid_iterator pointing to the ( \b last + 1 ) block of the stream
     //! \param nbuffers number of buffers for internal use
@@ -85,11 +87,11 @@ public:
         current_blk = prefetcher->pull_block();
     }
 
-    //! \brief Input stream operator, reads in \c record
+    //! Input stream operator, reads in \c record.
     //! \param record reference to the block record type,
     //!        contains value of the next record in the stream after the call of the operator
     //! \return reference to itself (stream object)
-    _Self & operator >> (reference record)
+    _Self& operator >> (reference record)
     {
 #ifdef BUF_ISTREAM_CHECK_END
         assert(not_finished);
@@ -97,7 +99,7 @@ public:
 
         record = current_blk->elem[current_elem++];
 
-        if (current_elem >= block_type::size)
+        if (UNLIKELY(current_elem >= block_type::size))
         {
             current_elem = 0;
 #ifdef BUF_ISTREAM_CHECK_END
@@ -110,23 +112,21 @@ public:
         return (*this);
     }
 
-    //! \brief Returns reference to the current record in the stream
-    //! \return reference to the current record in the stream
+    //! Returns reference to the current record in the stream.
     reference current()     /* const */
     {
         return current_blk->elem[current_elem];
     }
 
-    //! \brief Returns reference to the current record in the stream
-    //! \return reference to the current record in the stream
+    //! Returns reference to the current record in the stream.
     reference operator * ()     /* const */
     {
         return current_blk->elem[current_elem];
     }
 
-    //! \brief Moves to the next record in the stream
+    //! Moves to the next record in the stream.
     //! \return reference to itself after the advance
-    _Self & operator ++ ()
+    _Self& operator ++ ()
     {
 #ifdef BUF_ISTREAM_CHECK_END
         assert(not_finished);
@@ -134,7 +134,7 @@ public:
 
         current_elem++;
 
-        if (current_elem >= block_type::size)
+        if (UNLIKELY(current_elem >= block_type::size))
         {
             current_elem = 0;
 #ifdef BUF_ISTREAM_CHECK_END
@@ -146,8 +146,8 @@ public:
         return *this;
     }
 
-    //! \brief Frees used internal objects
-    virtual ~buf_istream()
+    //! Frees used internal objects.
+    ~buf_istream()
     {
         delete prefetcher;
         delete[] prefetch_seq;
@@ -156,6 +156,6 @@ public:
 
 //! \}
 
-__STXXL_END_NAMESPACE
+STXXL_END_NAMESPACE
 
-#endif // !STXXL_BUF_ISTREAM_HEADER
+#endif // !STXXL_MNG_BUF_ISTREAM_HEADER
