@@ -17,13 +17,13 @@
 #include <stxxl/bits/namespace.h>
 
 
-__STXXL_BEGIN_NAMESPACE
+STXXL_BEGIN_NAMESPACE
 
 template <typename U>
-inline void STXXL_UNUSED(const U &)
+inline void STXXL_UNUSED(const U&)
 { }
 
-__STXXL_END_NAMESPACE
+STXXL_END_NAMESPACE
 
 #endif // !STXXL_UNUSED_HEADER
 // vim: et:ts=4:sw=4
